# -*- coding: utf-8 *-*
#
# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the
# OpenSSL library under certain conditions as described in each
# individual source file, and distribute linked combinations
# including the two.
# You must obey the GNU General Public License in all respects
# for all of the code used other than OpenSSL.  If you modify
# file(s) with this exception, you may extend this exception to your
# version of the file(s), but you are not obligated to do so.  If you
# do not wish to do so, delete this exception statement from your
# version.  If you delete this exception statement from all source
# files in the program, then also delete it here.
"""Test the files search module."""

import os
import re

from twisted.internet import defer
from twisted.trial.unittest import TestCase

from ubuntuone.syncdaemon import files_search


class FakeVolumeManager(object):
    """Fake VolumeManager."""

    def get_folders(self):
        """Return the u1 folders."""
        return ('/home/u1/', '/home/.local/udfs/', '/home/.local/shared',
            '/home/.local/shares')


class FakeFilesystemManager(object):
    """Fake FilesystemManager."""

    def __init__(self):
        self.pattern = ''
        self.vm = FakeVolumeManager()

    def get_paths_by_pattern(self, pattern):
        """Store the pattern received."""
        self.pattern = pattern


class FilesSearchTestCase(TestCase):
    """Test the SyncMenu."""

    @defer.inlineCallbacks
    def setUp(self):
        yield super(FilesSearchTestCase, self).setUp()
        self.fsm = FakeFilesystemManager()
        self.search = files_search.SearchFiles(self.fsm)
        root, udf_dir, shared_dir, _ = self.fsm.vm.get_folders()
        paths = "(%s|%s|%s)" % (re.escape(root), re.escape(udf_dir),
            re.escape(shared_dir))
        self.basic_pattern = paths + ".*" + os.sep + ".*%s.*$"

    def test_simple_string(self):
        """Check the pattern is the same string."""
        pattern = 'filename'
        self.search.search(pattern)
        expected = self.basic_pattern % pattern
        self.assertEqual(expected, self.fsm.pattern)

    def test_escaped_string(self):
        """Check the pattern is the same string."""
        self.search.search('file_name')
        expected = self.basic_pattern % 'file\\_name'
        self.assertEqual(expected, self.fsm.pattern)

    def test_string_with_space(self):
        """Check the pattern is the same string."""
        self.search.search('file name')
        expected = self.basic_pattern % 'file.+name'
        self.assertEqual(expected, self.fsm.pattern)
