# -*- coding: utf-8 -*-
#
# Copyright 2011-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the
# OpenSSL library under certain conditions as described in each
# individual source file, and distribute linked combinations
# including the two.
# You must obey the GNU General Public License in all respects
# for all of the code used other than OpenSSL.  If you modify
# file(s) with this exception, you may extend this exception to your
# version of the file(s), but you are not obligated to do so.  If you
# do not wish to do so, delete this exception statement from your
# version.  If you delete this exception statement from all source
# files in the program, then also delete it here.
"""Searchs for files inside the U1 folder."""

import os
import re


class SearchFiles(object):
    """Seearch for specific patterns in the U1 files names."""

    def __init__(self, fs):
        self.fs = fs
        root, udf_dir, shared_dir, _ = self.fs.vm.get_folders()
        paths = "(%s|%s|%s)" % (re.escape(root), re.escape(udf_dir),
            re.escape(shared_dir))
        self.pattern = paths + ".*" + os.sep + ".*%s.*$"

    def search(self, pattern=''):
        """Search for the files that contains name."""
        keywords = '.+'.join(re.escape(pattern).split('\\ '))
        search = self.pattern % keywords
        results = self.fs.get_paths_by_pattern(search)
        return results
